[![PyPI version](https://img.shields.io/pypi/v/pysfa.svg?maxAge=3600)](https://pypi.org/project/pysfa/)[![PyPI downloads](https://img.shields.io/pypi/dm/pysfa.svg?maxAge=21600)](https://pypistats.org/packages/pysfa)

**pycreg** is a Python package for machine learing with convex regression built on [`pyStoNED`](https://github.com/ds2010/pyStoNED). 

The core aims of this package are:
* make convex regression models "easy to call" from python,
* interface with [`pyStoNED`](https://github.com/ds2010/pyStoNED),
* focus on a "machine learning" perspective, i.e.: predictive task, hyper-parameters should be obtained by a data-driven method such as cross-validation.

## Installation

The [`cvxreg`](https://pypi.org/project/pycreg) package is now avaiable on PyPI and the latest development version can be installed from the Github repository [`ConvexRegression`](https://github.com/ConvexRegression/ConvexRegression). Please feel free to download and test it. We welcome any bug reports and feedback.

#### PyPI 

    pip install cvxreg

